==> owncloud-10.0.3.tgz: owncloud/apps/files/l10n/fa.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "فضای ذخیره‌سازی نامعتبر",
    "Unknown error" : "خطای نامشخص",
    "All files" : "تمامی فایل‌ها",
    "Saved" : "ذخیره شد",
    "Home" : "خانه",
    "Close" : "بستن",
    "Favorites" : "موارد محبوب",
    "Upload cancelled." : "بار گذاری لغو شد",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "امکان آپلود {filename} وجود ندارد، پوشه‌ای با این نام یا فایلی با حجم 0 بایت با این نام وجود دارد",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "ظرفیت لازم وجود ندارد، شما آپلودی با حجم {size1}  را انجام میدهید اما تنها {size2} فضا باقی مانده است",
    "Uploading..." : "درحال بارگذاری...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "آپلودکردن پرونده در حال پیشرفت است. در صورت خروج از صفحه آپلود لغو میگردد. ",
    "Actions" : "فعالیت ها",
    "Download" : "دانلود",
    "Rename" : "تغییرنام",
    "Delete" : "حذف",
    "Unshare" : "لغو اشتراک",
    "Files" : "پرونده‌ها",
    "Details" : "جزئیات",
    "Select" : "انتخاب",
    "Pending" : "در انتظار",
    "Unable to determine date" : "امکان تعیین تاریخ وجود ندارد",
    "Invalid path" : "مسیر اشتباه",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تاریخ",
    "_%n folder_::_%n folders_" : ["%n پوشه"],
    "_%n file_::_%n files_" : ["%n فایل"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "شما دسترسی مجاز برای آپلود یا ایجاد فایل در اینجا را ندارید",
    "_Uploading %n file_::_Uploading %n files_" : ["در حال بارگذاری %n فایل"],
    "New" : "جدید",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "فضای ذخیر‌سازی {owner}  پر شده است، امکان بروزرسانی یا هم‌گام‌سازی بیشتر وجود ندارد!",
    "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "فضای  {owner} تقریبا پر شده است ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "فضای ذخیره ی شما تقریبا پر است ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["تطبیق '{filter}'"],
    "Path" : "مسیر",
    "_%n byte_::_%n bytes_" : ["%n بایت"],
    "Favorited" : "برگزیده شده",
    "Favorite" : "برگزیده",
    "Folder" : "پوشه",
    "New folder" : "پوشه جدید",
    "{newname} already exists" : "{newname}  هم‌اکنون وجود دارد",
    "Upload" : "بارگزاری",
    "An error occurred while trying to update the tags" : "یک خطا در حین بروزرسانی برچسب‌ها رخ داده است",
    "A new file or folder has been <strong>created</strong>" : "فایل یا پوشه ای <strong>ایجاد</strong> شد",
    "A file or folder has been <strong>changed</strong>" : "فایل یا پوشه ای به <strong>تغییر</strong> یافت",
    "A file or folder has been <strong>deleted</strong>" : "فایل یا پوشه ای به <strong>حذف</strong> شد",
    "A file or folder has been <strong>restored</strong>" : "یک فایل یا پوشه <strong>بازگردانی شد</strong>",
    "You created %1$s" : "شما %1$s را ایجاد کردید",
    "%2$s created %1$s" : "%2$s مورد %1$s را ایجاد کرد",
    "%1$s was created in a public folder" : "%1$s در پوشه ی عمومی ایجاد شد",
    "You changed %1$s" : "شما %1$s را تغییر دادید",
    "%2$s changed %1$s" : "%2$s مورد %1$s را تغییر داد",
    "You deleted %1$s" : "شما %1$s را حذف کردید",
    "%2$s deleted %1$s" : "%2$s مورد %1$s را حذف کرد",
    "You restored %1$s" : "شما %1$s را بازگردانی کردید",
    "%2$s restored %1$s" : "%2$s %1$s را بازگردانی کرد",
    "Changed by %2$s" : "تغییریافته توسط %2$s",
    "Deleted by %2$s" : "حذف شده توسط %2$s",
    "Restored by %2$s" : "بازگردانی شده توسط  %2$s",
    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
    "File handling" : "اداره پرونده ها",
    "Maximum upload size" : "حداکثر اندازه بارگزاری",
    "max. possible: " : "حداکثرمقدارممکن:",
    "Save" : "ذخیره",
    "Settings" : "تنظیمات",
    "WebDAV" : "WebDAV",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
    "No favorites" : "هیچ برگزیده",
    "Files and folders you mark as favorite will show up here" : "فایل‌ها و پوشه‌های انتخاب شده به عنوان برگزیده توسط شما، در اینجا نمایش داده می‌شود",
    "Text file" : "فایل متنی"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/apps/files/l10n/fa.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "فضای ذخیره‌سازی نامعتبر",
    "Unknown error" : "خطای نامشخص",
    "All files" : "تمامی فایل‌ها",
    "Saved" : "ذخیره شد",
    "Home" : "خانه",
    "Close" : "بستن",
    "Favorites" : "موارد محبوب",
    "Upload cancelled." : "بار گذاری لغو شد",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "امکان آپلود {filename} وجود ندارد، پوشه‌ای با این نام یا فایلی با حجم 0 بایت با این نام وجود دارد",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "ظرفیت لازم وجود ندارد، شما آپلودی با حجم {size1}  را انجام میدهید اما تنها {size2} فضا باقی مانده است",
    "Uploading..." : "درحال بارگذاری...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "آپلودکردن پرونده در حال پیشرفت است. در صورت خروج از صفحه آپلود لغو میگردد. ",
    "Actions" : "فعالیت ها",
    "Download" : "دانلود",
    "Rename" : "تغییرنام",
    "Delete" : "حذف",
    "Unshare" : "لغو اشتراک",
    "Files" : "پرونده‌ها",
    "Details" : "جزئیات",
    "Select" : "انتخاب",
    "Pending" : "در انتظار",
    "Unable to determine date" : "امکان تعیین تاریخ وجود ندارد",
    "Invalid path" : "مسیر اشتباه",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تاریخ",
    "_%n folder_::_%n folders_" : ["%n پوشه"],
    "_%n file_::_%n files_" : ["%n فایل"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "شما دسترسی مجاز برای آپلود یا ایجاد فایل در اینجا را ندارید",
    "_Uploading %n file_::_Uploading %n files_" : ["در حال بارگذاری %n فایل"],
    "New" : "جدید",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "فضای ذخیر‌سازی {owner}  پر شده است، امکان بروزرسانی یا هم‌گام‌سازی بیشتر وجود ندارد!",
    "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "فضای  {owner} تقریبا پر شده است ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "فضای ذخیره ی شما تقریبا پر است ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["تطبیق '{filter}'"],
    "Path" : "مسیر",
    "_%n byte_::_%n bytes_" : ["%n بایت"],
    "Favorited" : "برگزیده شده",
    "Favorite" : "برگزیده",
    "Folder" : "پوشه",
    "New folder" : "پوشه جدید",
    "{newname} already exists" : "{newname}  هم‌اکنون وجود دارد",
    "Upload" : "بارگزاری",
    "An error occurred while trying to update the tags" : "یک خطا در حین بروزرسانی برچسب‌ها رخ داده است",
    "A new file or folder has been <strong>created</strong>" : "فایل یا پوشه ای <strong>ایجاد</strong> شد",
    "A file or folder has been <strong>changed</strong>" : "فایل یا پوشه ای به <strong>تغییر</strong> یافت",
    "A file or folder has been <strong>deleted</strong>" : "فایل یا پوشه ای به <strong>حذف</strong> شد",
    "A file or folder has been <strong>restored</strong>" : "یک فایل یا پوشه <strong>بازگردانی شد</strong>",
    "You created %1$s" : "شما %1$s را ایجاد کردید",
    "%2$s created %1$s" : "%2$s مورد %1$s را ایجاد کرد",
    "%1$s was created in a public folder" : "%1$s در پوشه ی عمومی ایجاد شد",
    "You changed %1$s" : "شما %1$s را تغییر دادید",
    "%2$s changed %1$s" : "%2$s مورد %1$s را تغییر داد",
    "You deleted %1$s" : "شما %1$s را حذف کردید",
    "%2$s deleted %1$s" : "%2$s مورد %1$s را حذف کرد",
    "You restored %1$s" : "شما %1$s را بازگردانی کردید",
    "%2$s restored %1$s" : "%2$s %1$s را بازگردانی کرد",
    "Changed by %2$s" : "تغییریافته توسط %2$s",
    "Deleted by %2$s" : "حذف شده توسط %2$s",
    "Restored by %2$s" : "بازگردانی شده توسط  %2$s",
    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
    "File handling" : "اداره پرونده ها",
    "Maximum upload size" : "حداکثر اندازه بارگزاری",
    "max. possible: " : "حداکثرمقدارممکن:",
    "Save" : "ذخیره",
    "Settings" : "تنظیمات",
    "WebDAV" : "WebDAV",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
    "No favorites" : "هیچ برگزیده",
    "Files and folders you mark as favorite will show up here" : "فایل‌ها و پوشه‌های انتخاب شده به عنوان برگزیده توسط شما، در اینجا نمایش داده می‌شود",
    "Text file" : "فایل متنی",
    "File could not be found" : "پرونده یافت نشد",
    "Target folder does not exist any more" : "پوشه مورد نظر دیگر وجود ندارد",
    "Private link:  Only people who have access to the file/folder can use it. Use it as a permanent link for yourself or to point others to files within shares" : "لینک خصوصی: تنها کسانی که به پرونده/پوشه ها دسترسی دارند می توانند از آن استفاده کنند. از آن به عنوان یک لینک دائمی برای خود یا برای اشاره دیگران به پرونده های مشترک استفاده نمایید",
    "Upload timeout for file \"{file}\"" : "زمان بارگذاری برای \"{file}\" به پایان رسید",
    "Show hidden files" : "نمایش پرونده های مخفی",
    "New text file.txt" : "متن جدید file.txt",
    "Storage is temporarily not available" : "فضای ذخیره سازی موقتا در دسترس نیست",
    "Disconnect storage" : "قطع فضای ذخیره سازی",
    "Processing files..." : "پردازش پرونده ها...",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} از {totalSize} ({bitrate})",
    "{newName} already exists" : "{newName} اکنون وجود دارد",
    "No entries in this folder match {filter}" : "هیچ ورودی‌ای در این پوشه با '{filter}' تطبیق ندارد",
    "Limit notifications about creation and changes to your <strong>favorite files</strong>" : "اعلان محدودیت ها در مورد ایجاد و تغییر در <strong>پرونده های مورد علاقه شما</strong>",
    "You don't have permissions to access this file/folder - Please contact the owner to share it with you." : "شما اجازه دسترسی به این پرونده/پوشه را ندارید - لطفا با مالک تماس بگیرید تا آن را با شما به اشتراک بگذارد.",
    "Error when assembling chunks, status code {status}" : "خطا هنگام سرهم بندی قطعات، کد وضعیت {status}",
    "Not enough free space" : "فضای آزاد کافی نیست"
},
"nplurals=1; plural=0;");
